@@ -46,7 +46,9 @@ merge_rasters <- function(input_rasters,
   if (file.exists(output_raster) &&
     !overwrite &&
     !any(options == "-overwrite")) {
-    stop("File exists at ", output_raster, " and overwrite is not TRUE.")
+    rlang::abort(
+      glue::glue("File exists at {output_raster} and overwrite is not TRUE.")
+    )
   }
 
   if (!any(options == "-overwrite") && overwrite) {
@@ -64,9 +66,9 @@ merge_rasters <- function(input_rasters,
         )
       },
       error = function(e) {
-        warning(
-          "\nReceived error from gdalwarp.",
-          "Trying another method. This may take longer than normal..."
+        rlang::warn(
+          c("Received error from gdalwarp, trying a fallback method",
+            i = "This may take longer than expected"),
         )
         merge_rasters_deprecated(input_rasters, output_raster, options)
       }
@@ -84,11 +86,6 @@ merge_rasters <- function(input_rasters,
 merge_rasters_deprecated <- function(input_rasters,
                                      output_raster = tempfile(fileext = ".tif"),
                                      options = character(0)) {
-  if (length(options) > 0) {
-    if(!(length(options == 1) && options == "-overwrite")) {
-      warning("Options are not respected when trying to merge rasters with differing numbers of bands") # nolint
-    }
-  }
 
   temp_output <- tempfile(fileext = ".vrt")
   sf::gdal_utils(
@@ -103,10 +100,9 @@ merge_rasters_deprecated <- function(input_rasters,
     options = options
   )
 
-  message(
-    "\n...done.\n",
-    "The alternate method seems to have worked!\n",
-    "If your merged output looks right, you can ignore the above error.\n"
+  rlang::inform(
+    c("The alternative method seems to have worked!",
+      i = "If your merged output looks right, you can ignore the above error.")
   )
 
   return(invisible(output_raster))
