@@ -1,12 +1,15 @@
 test_that("combine_overlays works", {
+  testthat::skip_if_not_installed("tiff")
   x_tmp <- tempfile(fileext = ".png")
   y_tmp <- tempfile(fileext = ".png")
 
-  x <- combine_overlays("testdata/NAIPPlus.png",
+  x <- combine_overlays(
+    "testdata/NAIPPlus.png",
     "testdata/vto_point.png",
     output_file = x_tmp
   )
-  y <- combine_overlays("testdata/NAIPPlus_gr.tif",
+  y <- combine_overlays(
+    "testdata/NAIPPlus_gr.tif",
     "testdata/vto_point.png",
     output_file = y_tmp
   )
@@ -16,12 +19,14 @@ test_that("combine_overlays works", {
     png::readPNG(y_tmp)
   )
 
-  x <- combine_overlays("testdata/NAIPPlus.png",
+  x <- combine_overlays(
+    "testdata/NAIPPlus.png",
     "testdata/vto_point.png",
     output_file = x_tmp,
     transparency = 18
   )
-  y <- combine_overlays("testdata/NAIPPlus_gr.tif",
+  y <- combine_overlays(
+    "testdata/NAIPPlus_gr.tif",
     "testdata/vto_point.png",
     output_file = y_tmp,
     transparency = 0.18
